#!/bin/bash

# -------------------------------
# On first error exit bash script
# -------------------------------
set -e

# ----------
# Start time
# ----------
date +'%Y-%m-%d %H:%M:%S'


# -----------------------
# Install flatpak-builder
# -----------------------
flatpak install -y flathub org.flatpak.Builder


# -----------------------
# Install flatpak SDK
# -----------------------
flatpak install -y flathub org.freedesktop.Platform//22.08 org.freedesktop.Sdk//22.08


# --------------------
# Create Manifest file
# --------------------
cat > com.github.pwsafe.pwsafe.yml <<EOF
app-id: com.github.pwsafe.pwsafe
runtime: org.freedesktop.Platform
runtime-version: '22.08'
sdk: org.freedesktop.Sdk
command: pwsafe
rename-icon: pwsafe
rename-desktop-file: pwsafe.desktop
finish-args:
  - --socket=fallback-x11
  - --socket=wayland
  - --share=ipc
  - --filesystem=xdg-documents
  - --env=PWS_HELPDIR=/app/share/passwordsafe/help/
  # YubiKey USB access
  - --device=all
cleanup-commands:
  # Delete unnecessary files after build 
  - rm -rf /app/share/doc/xerces-c/
  - rm -rf /app/include/xercesc/dom/*.hpp
  - rm -rf /app/include/xercesc/dom/impl/*.hpp
  - rm -rf /app/include/xercesc/framework/*.hpp
  - rm -rf /app/include/xercesc/framework/psvi/*.hpp
  - rm -rf /app/include/xercesc/internal/*.hpp
  - rm -rf /app/include/xercesc/parsers/*.hpp
  - rm -rf /app/include/xercesc/sax/*.hpp
  - rm -rf /app/include/xercesc/sax2/*.hpp
  - rm -rf /app/include/xercesc/util/*.hpp
  - rm -rf /app/include/xercesc/util/FileManagers/*.hpp
  - rm -rf /app/include/xercesc/util/MsgLoaders/*.hpp
  - rm -rf /app/include/xercesc/util/MsgLoaders/InMemory/*.hpp
  - rm -rf /app/include/xercesc/util/MutexManagers/*.hpp
  - rm -rf /app/include/xercesc/util/NetAccessors/Curl/*.hpp
  - rm -rf /app/include/xercesc/util/Transcoders/ICU/*.hpp
  - rm -rf /app/include/xercesc/util/regx/*.hpp
  - rm -rf /app/include/xercesc/validators/DTD/*.hpp
  - rm -rf /app/include/xercesc/validators/common/*.hpp
  - rm -rf /app/include/xercesc/validators/datatype/*.hpp
  - rm -rf /app/include/xercesc/validators/datatype/*.hpp
  - rm -rf /app/include/xercesc/validators/schema/*.hpp
  - rm -rf /app/include/xercesc/validators/schema/identity/*.hpp
  - rm -rf /app/include/xercesc/xinclude/*.hpp
  - rm -rf /app/include/qrencode.h
  - rm -rf /app/include/xercesc/dom/impl/*.c
  - rm -rf /app/include/xercesc/framework/psvi/*.c
  - rm -rf /app/include/xercesc/util/*.c
  - rm -rf /app/lib/cmake/XercesC/*.cmake

modules:
  - name: libqrencode
    buildsystem: autotools
    sources:
      - type: git
        url: https://github.com/fukuchi/libqrencode/
        tag: v4.1.1
        commit: 715e29fd4cd71b6e452ae0f4e36d917b43122ce8

  - name: wxwidgets
    cleanup:
      - /bin
      - /include
      - /lib/cmake
      - /lib/wx
      - /share
    sources:
      - type: git
        url: https://github.com/wxWidgets/wxWidgets/
        tag: v3.2.2.1
        commit: a812fffda3fe686c94e24bff27e8effd96e4de64

  - name: Xerces-C
    buildsystem: cmake-ninja
    sources:
      - type: git
        url: https://github.com/apache/xerces-c
        tag: v3.2.4
        commit: 5052c90b067dcc347d58822b450897d16e2c31e5

  - name: pwsafe
    builddir: true
    buildsystem: cmake
    config-opts:
      - -DNO_GTEST=ON
      - -DGTEST_BUILD=OFF
    sources:
      - type: git
        url: https://github.com/pwsafe/pwsafe/
        tag: 1.17.0
        commit: f4a7dd6aeff9428eebc45dcb52f50630ebd0b7b1

EOF


# -------------
# Build flatpak
# -------------
flatpak run org.flatpak.Builder --force-clean build-dir com.github.pwsafe.pwsafe.yml


# -------------------------------------
# Uninstall pwsafe flatpak if installed
# -------------------------------------
is_pwsafe_installed=$(flatpak list | grep "com.github.pwsafe.pwsafe" | wc -l)
if [[ $is_pwsafe_installed -eq 1 ]]; then
    flatpak uninstall -y com.github.pwsafe.pwsafe
fi


# -----------------------
# Install flatpak locally
# -----------------------
flatpak run org.flatpak.Builder --user --install --force-clean build-dir com.github.pwsafe.pwsafe.yml


# ----------------------
# List installed flatpak
# ----------------------
flatpak list | grep pwsafe


# -----------
# Run flatpak
# -----------
flatpak run com.github.pwsafe.pwsafe &


# ----------
# End time
# ----------
date +'%Y-%m-%d %H:%M:%S'
